==> stylish-haskell-0.14.3.0-18-riscv64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stylish-haskell
version:              0.14.3.0
visibility:           public
id:                   stylish-haskell-0.14.3.0-FwGitWkEveR5gLjjhn52Qh
key:                  stylish-haskell-0.14.3.0-FwGitWkEveR5gLjjhn52Qh
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  840c0cde3a5adb395ae4960042ca073c
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stylish-haskell-0.14.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.3.0-FwGitWkEveR5gLjjhn52Qh
depends:
    Cabal-3.6.3.0 HsYAML-0.2.1.3-CKDh8C7ORvL33YMNhb0U1W
    HsYAML-aeson-0.2.0.1-CNax88AhoY87SJVK1EidZj
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    ghc-9.2.8 ghc-boot-9.2.8 ghc-boot-th-9.2.8
    ghc-lib-parser-ex-9.2.1.1-2wJWCYR2oBS7seNPbu7R8W mtl-2.2.2
    regex-tdfa-1.3.2.2-9KQuOdDpiBL9UBsQEK6k8E
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s text-1.2.5.0

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.14.4.0-27.1-riscv64.pkg.tar.zst: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stylish-haskell
version:              0.14.4.0
visibility:           public
id:                   stylish-haskell-0.14.4.0-BLLceFqQqnY3QYU4FSAtHN
key:                  stylish-haskell-0.14.4.0-BLLceFqQqnY3QYU4FSAtHN
license:              BSD-3-Clause
copyright:            2012 Jasper Van der Jeugt
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             https://github.com/haskell/stylish-haskell
synopsis:             Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:

    <https://github.com/haskell/stylish-haskell/blob/master/README.markdown>

category:             Language
abi:                  248a70898ef7e0e29a7ccd894807ab90
exposed:              True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Config
    Language.Haskell.Stylish.GHC Language.Haskell.Stylish.Module
    Language.Haskell.Stylish.Parse Language.Haskell.Stylish.Printer
    Language.Haskell.Stylish.Step Language.Haskell.Stylish.Step.Data
    Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.ModuleHeader
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax

hidden-modules:
    Language.Haskell.Stylish.Align Language.Haskell.Stylish.Block
    Language.Haskell.Stylish.Comments
    Language.Haskell.Stylish.Config.Cabal
    Language.Haskell.Stylish.Config.Internal
    Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Ordering
    Language.Haskell.Stylish.Util Language.Haskell.Stylish.Verbose
    Paths_stylish_haskell

import-dirs:          /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stylish-haskell-0.14.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stylish-haskell
hs-libraries:         HSstylish-haskell-0.14.4.0-BLLceFqQqnY3QYU4FSAtHN
depends:
    Cabal-3.8.1.0 HsYAML-0.2.1.3-AINukzkI0osDAEAPfv3L1J
    HsYAML-aeson-0.2.0.1-9YOKvHDuSQwEHVYEMwbsaw
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 ghc-boot-9.4.8 ghc-boot-th-9.4.8
    ghc-lib-parser-ex-9.4.0.0-IemxHL6COmYBh83i5aWdmY mtl-2.2.2
    regex-tdfa-1.3.2.4-LXwWfM9riXbAuaKHkk8lra
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv text-2.0.2

haddock-interfaces:   /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html:         /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
